==> keycloak-model-map-20.0.3-sources.jar: org/keycloak/models/map/role/MapRoleEntityFields.java <==
package org.keycloak.models.map.role;
public enum MapRoleEntityFields implements org.keycloak.models.map.common.EntityField<org.keycloak.models.map.role.MapRoleEntity> {
    ID {
        public static final String FIELD_NAME = "Id";
        public static final String FIELD_NAME_DASHED = "id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.role.MapRoleEntity e) {
            return (String) e.getId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.role.MapRoleEntity e, T value) {
            e.setId((String) value);
        }
    },
    ATTRIBUTES {
        public static final String FIELD_NAME = "Attributes";
        public static final String FIELD_NAME_DASHED = "attributes";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.Map.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getMapKeyClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getMapValueClass() {
            return java.util.List.class;
        }
        @SuppressWarnings("unchecked") @Override public <K, T> void mapPut(org.keycloak.models.map.role.MapRoleEntity e, K key, T value) {
            e.setAttribute((String) key, (java.util.List<String>) value);
        }
        @SuppressWarnings("unchecked") @Override public <K> Void mapRemove(org.keycloak.models.map.role.MapRoleEntity e, K p0) {
            e.removeAttribute((String) p0); return null;
        }
        @SuppressWarnings("unchecked") @Override public java.util.Map<String,java.util.List<String>> get(org.keycloak.models.map.role.MapRoleEntity e) {
            return (java.util.Map<String,java.util.List<String>>) e.getAttributes();
        }
        @SuppressWarnings("unchecked") @Override public <K> java.util.List<String> mapGet(org.keycloak.models.map.role.MapRoleEntity e, K key) {
            return (java.util.List<String>) e.getAttribute((String) key);
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.role.MapRoleEntity e, T value) {
            e.setAttributes((java.util.Map<String,java.util.List<String>>) value);
        }
    },
    CLIENT_ID {
        public static final String FIELD_NAME = "ClientId";
        public static final String FIELD_NAME_DASHED = "client-id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.role.MapRoleEntity e, T value) {
            e.setClientId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.role.MapRoleEntity e) {
            return (String) e.getClientId();
        }
    },
    CLIENT_ROLE {
        public static final String FIELD_NAME = "ClientRole";
        public static final String FIELD_NAME_DASHED = "client-role";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return Boolean.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.role.MapRoleEntity e, T value) {
            e.setClientRole((Boolean) value);
        }
        @SuppressWarnings("unchecked") @Override public Boolean get(org.keycloak.models.map.role.MapRoleEntity e) {
            return (Boolean) e.isClientRole();
        }
    },
    COMPOSITE_ROLES {
        public static final String FIELD_NAME = "CompositeRoles";
        public static final String FIELD_NAME_DASHED = "composite-roles";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.Set.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getCollectionElementClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public <T> void collectionAdd(org.keycloak.models.map.role.MapRoleEntity e, T value) {
            e.addCompositeRole((String) value);
        }
        @SuppressWarnings("unchecked") @Override public java.util.Set<String> get(org.keycloak.models.map.role.MapRoleEntity e) {
            return (java.util.Set<String>) e.getCompositeRoles();
        }
        @SuppressWarnings("unchecked") @Override public <T> Void collectionRemove(org.keycloak.models.map.role.MapRoleEntity e, T p0) {
            e.removeCompositeRole((String) p0); return null;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.role.MapRoleEntity e, T value) {
            e.setCompositeRoles((java.util.Set<String>) value);
        }
    },
    DESCRIPTION {
        public static final String FIELD_NAME = "Description";
        public static final String FIELD_NAME_DASHED = "description";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.role.MapRoleEntity e) {
            return (String) e.getDescription();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.role.MapRoleEntity e, T value) {
            e.setDescription((String) value);
        }
    },
    NAME {
        public static final String FIELD_NAME = "Name";
        public static final String FIELD_NAME_DASHED = "name";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.role.MapRoleEntity e, T value) {
            e.setName((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.role.MapRoleEntity e) {
            return (String) e.getName();
        }
    },
    REALM_ID {
        public static final String FIELD_NAME = "RealmId";
        public static final String FIELD_NAME_DASHED = "realm-id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.role.MapRoleEntity e) {
            return (String) e.getRealmId();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.role.MapRoleEntity e, T value) {
            e.setRealmId((String) value);
        }
    },
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/role/MapRoleEntityFields.java <==
package org.keycloak.models.map.role;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public enum MapRoleEntityFields implements org.keycloak.models.map.common.EntityField<org.keycloak.models.map.role.MapRoleEntity> {
    ID {
        public static final String FIELD_NAME = "Id";
        public static final String FIELD_NAME_DASHED = "id";
        public static final String FIELD_NAME_CAMEL_CASE = "id";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.role.MapRoleEntity e, T value) {
            e.setId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.role.MapRoleEntity e) {
            return (String) e.getId();
        }
    },
    ATTRIBUTES {
        public static final String FIELD_NAME = "Attributes";
        public static final String FIELD_NAME_DASHED = "attributes";
        public static final String FIELD_NAME_CAMEL_CASE = "attributes";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.Map.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getMapKeyClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getMapValueClass() {
            return java.util.List.class;
        }
        @SuppressWarnings("unchecked") @Override public <K, T> void mapPut(org.keycloak.models.map.role.MapRoleEntity e, K key, T value) {
            e.setAttribute((String) key, (java.util.List<String>) value);
        }
        @SuppressWarnings("unchecked") @Override public <K> java.util.List<String> mapGet(org.keycloak.models.map.role.MapRoleEntity e, K key) {
            return (java.util.List<String>) e.getAttribute((String) key);
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.role.MapRoleEntity e, T value) {
            e.setAttributes((java.util.Map<String,java.util.List<String>>) value);
        }
        @SuppressWarnings("unchecked") @Override public <K> Void mapRemove(org.keycloak.models.map.role.MapRoleEntity e, K p0) {
            e.removeAttribute((String) p0); return null;
        }
        @SuppressWarnings("unchecked") @Override public java.util.Map<String,java.util.List<String>> get(org.keycloak.models.map.role.MapRoleEntity e) {
            return (java.util.Map<String,java.util.List<String>>) e.getAttributes();
        }
    },
    CLIENT_ID {
        public static final String FIELD_NAME = "ClientId";
        public static final String FIELD_NAME_DASHED = "client-id";
        public static final String FIELD_NAME_CAMEL_CASE = "clientId";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.role.MapRoleEntity e, T value) {
            e.setClientId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.role.MapRoleEntity e) {
            return (String) e.getClientId();
        }
    },
    COMPOSITE_ROLES {
        public static final String FIELD_NAME = "CompositeRoles";
        public static final String FIELD_NAME_DASHED = "composite-roles";
        public static final String FIELD_NAME_CAMEL_CASE = "compositeRoles";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return java.util.Set.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public Class<?> getCollectionElementClass() {
            return String.class;
        }
        @SuppressWarnings("unchecked") @Override public java.util.Set<String> get(org.keycloak.models.map.role.MapRoleEntity e) {
            return (java.util.Set<String>) e.getCompositeRoles();
        }
        @SuppressWarnings("unchecked") @Override public <T> Void collectionRemove(org.keycloak.models.map.role.MapRoleEntity e, T p0) {
            e.removeCompositeRole((String) p0); return null;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.role.MapRoleEntity e, T value) {
            e.setCompositeRoles((java.util.Set<String>) value);
        }
        @SuppressWarnings("unchecked") @Override public <T> void collectionAdd(org.keycloak.models.map.role.MapRoleEntity e, T value) {
            e.addCompositeRole((String) value);
        }
    },
    DESCRIPTION {
        public static final String FIELD_NAME = "Description";
        public static final String FIELD_NAME_DASHED = "description";
        public static final String FIELD_NAME_CAMEL_CASE = "description";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.role.MapRoleEntity e) {
            return (String) e.getDescription();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.role.MapRoleEntity e, T value) {
            e.setDescription((String) value);
        }
    },
    NAME {
        public static final String FIELD_NAME = "Name";
        public static final String FIELD_NAME_DASHED = "name";
        public static final String FIELD_NAME_CAMEL_CASE = "name";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.role.MapRoleEntity e) {
            return (String) e.getName();
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.role.MapRoleEntity e, T value) {
            e.setName((String) value);
        }
    },
    REALM_ID {
        public static final String FIELD_NAME = "RealmId";
        public static final String FIELD_NAME_DASHED = "realm-id";
        public static final String FIELD_NAME_CAMEL_CASE = "realmId";
        @SuppressWarnings("unchecked") @Override public Class<?> getFieldClass() {
            return String.class;
        }
        @Override public String getName() {
            return FIELD_NAME;
        }
        @Override public String getNameDashed() {
            return FIELD_NAME_DASHED;
        }
        @Override public String getNameCamelCase() {
            return FIELD_NAME_CAMEL_CASE;
        }
        @SuppressWarnings("unchecked") @Override public <T> void set(org.keycloak.models.map.role.MapRoleEntity e, T value) {
            e.setRealmId((String) value);
        }
        @SuppressWarnings("unchecked") @Override public String get(org.keycloak.models.map.role.MapRoleEntity e) {
            return (String) e.getRealmId();
        }
    },
}
